void _c_int00()
{
    /* Initialize Core Registers to avoid CCM Error */
    _coreInitRegisters_();

    /* Initialize Stack Pointers */
    _coreInitStackPointer_();

    /* Reset handler: the following instructions read from the system exception status register
     * to identify the cause of the CPU reset.
     */
    switch (getResetSource())
    {
    case POWERON_RESET:
    case DEBUG_RESET:
    case EXT_RESET:
    case OSC_FAILURE_RESET:
    case WATCHDOG_RESET:
    case WATCHDOG2_RESET:
    case CPU0_RESET:
    case SW_RESET:
    default:

		/* indicated by a forum question if system or cpu reset was issued
		 * Some types of reset don't disable the MPU so do it explicitly
		 * before any memory accesses are done
		 * https://e2e.ti.com/support/microcontrollers/arm-based-microcontrollers-group/arm-based-microcontrollers/f/arm-based-microcontrollers-forum/493739/rm57-reset-through-cpurstc-leaves-cpu-in-bad-state
		 */
		_mpuDisable_();

		/* Initialize L2RAM to avoid ECC errors right after power on */
        _memInit_();

        /* Enable CPU Event Export */
        /* This allows the CPU to signal any single-bit or double-bit errors detected
         * by its ECC logic for accesses to program flash or data RAM.
         */
        _coreEnableEventBusExport_();

        /* Check if there were ESM group3 errors during power-up.
         * These could occur during eFuse auto-load or during reads from flash OTP
         * during power-up. Device operation is not reliable and not recommended
         * in this case. */
        if ((esmREG->SR1[2]) != 0U)
        {
            esmGroup3Notification(esmREG,esmREG->SR1[2]);
        }

        /* Initialize System - Clock, Flash settings with Efuse self check */
        systemInit();

        /* Enable IRQ offset via Vic controller */
        _coreEnableIrqVicOffset_();

        /* Initialize VIM table */
        vimInit();

        /* Clear any pending ESM interrupts that made it here */
        esmInit();
        break;
    }

    MpuInit();

    _cacheEnable_();

    /* Fill stack in debug mode. */
#ifdef DEBUG
    _coreFillStack_();
#endif

    {
        extern uint32 _sidata, _sdata, _edata;
        extern uint32 _ksidata, _ksdata, _kedata;
        uint32* src,* dst;

        src = &_sidata;
        dst = &_sdata;

        while (dst < &_edata)
        {
            *dst++ = *src++;
        }

        src = &_ksidata;
        dst = &_ksdata;

        while (dst < &_kedata)
        {
            *dst++ = *src++;
        }
    }
    __libc_init_array();

    main();
    exit(0);
}